# py-logto
Python Client for Logto API.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.17.0:edge
- Package version: 1.0.1
- Generator version: 7.7.0

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/Housain-maina/py-logto.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/Housain-maina/py-logto.git`)

Then import the package:
```python
import py_logto
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import py_logto
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import py_logto
from py_logto.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost:3001
# See configuration.py for a list of all supported configuration parameters.
configuration = py_logto.Configuration(
    host = "http://localhost:3001"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): ManagementApi
configuration = py_logto.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with py_logto.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = py_logto.ApplicationsApi(api_client)
    application_id = 'application_id_example' # str | The unique identifier of the application.
    assign_application_roles_request = py_logto.AssignApplicationRolesRequest() # AssignApplicationRolesRequest | 

    try:
        # Assign API resource roles to application
        api_instance.assign_application_roles(application_id, assign_application_roles_request)
    except ApiException as e:
        print("Exception when calling ApplicationsApi->assign_application_roles: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:3001*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApplicationsApi* | [**assign_application_roles**](docs/ApplicationsApi.md#assign_application_roles) | **POST** /api/applications/{applicationId}/roles | Assign API resource roles to application
*ApplicationsApi* | [**create_application**](docs/ApplicationsApi.md#create_application) | **POST** /api/applications | Create an application
*ApplicationsApi* | [**create_application_protected_app_metadata_custom_domain**](docs/ApplicationsApi.md#create_application_protected_app_metadata_custom_domain) | **POST** /api/applications/{id}/protected-app-metadata/custom-domains | Add a custom domain to the protected application.
*ApplicationsApi* | [**create_application_user_consent_organization**](docs/ApplicationsApi.md#create_application_user_consent_organization) | **POST** /api/applications/{id}/users/{userId}/consent-organizations | Grant a list of organization access of a user for a application.
*ApplicationsApi* | [**create_application_user_consent_scope**](docs/ApplicationsApi.md#create_application_user_consent_scope) | **POST** /api/applications/{applicationId}/user-consent-scopes | Assign user consent scopes to application.
*ApplicationsApi* | [**delete_application**](docs/ApplicationsApi.md#delete_application) | **DELETE** /api/applications/{id} | Delete application
*ApplicationsApi* | [**delete_application_protected_app_metadata_custom_domain**](docs/ApplicationsApi.md#delete_application_protected_app_metadata_custom_domain) | **DELETE** /api/applications/{id}/protected-app-metadata/custom-domains/{domain} | Delete a custom domain.
*ApplicationsApi* | [**delete_application_role**](docs/ApplicationsApi.md#delete_application_role) | **DELETE** /api/applications/{applicationId}/roles/{roleId} | Remove a API resource role from application
*ApplicationsApi* | [**delete_application_user_consent_organization**](docs/ApplicationsApi.md#delete_application_user_consent_organization) | **DELETE** /api/applications/{id}/users/{userId}/consent-organizations/{organizationId} | Revoke a user&#39;s access to an organization for a application.
*ApplicationsApi* | [**delete_application_user_consent_scope**](docs/ApplicationsApi.md#delete_application_user_consent_scope) | **DELETE** /api/applications/{applicationId}/user-consent-scopes/{scopeType}/{scopeId} | Remove user consent scope from application.
*ApplicationsApi* | [**get_application**](docs/ApplicationsApi.md#get_application) | **GET** /api/applications/{id} | Get application
*ApplicationsApi* | [**get_application_sign_in_experience**](docs/ApplicationsApi.md#get_application_sign_in_experience) | **GET** /api/applications/{applicationId}/sign-in-experience | Get the application level sign-in experience
*ApplicationsApi* | [**list_application_organizations**](docs/ApplicationsApi.md#list_application_organizations) | **GET** /api/applications/{id}/organizations | Get application organizations
*ApplicationsApi* | [**list_application_protected_app_metadata_custom_domains**](docs/ApplicationsApi.md#list_application_protected_app_metadata_custom_domains) | **GET** /api/applications/{id}/protected-app-metadata/custom-domains | Get the list of custom domains of the protected application.
*ApplicationsApi* | [**list_application_roles**](docs/ApplicationsApi.md#list_application_roles) | **GET** /api/applications/{applicationId}/roles | Get application API resource roles
*ApplicationsApi* | [**list_application_user_consent_organizations**](docs/ApplicationsApi.md#list_application_user_consent_organizations) | **GET** /api/applications/{id}/users/{userId}/consent-organizations | List all the user consented organizations of a application.
*ApplicationsApi* | [**list_application_user_consent_scopes**](docs/ApplicationsApi.md#list_application_user_consent_scopes) | **GET** /api/applications/{applicationId}/user-consent-scopes | List all the user consent scopes of an application.
*ApplicationsApi* | [**list_applications**](docs/ApplicationsApi.md#list_applications) | **GET** /api/applications | Get applications
*ApplicationsApi* | [**replace_application_roles**](docs/ApplicationsApi.md#replace_application_roles) | **PUT** /api/applications/{applicationId}/roles | Update API resource roles for application
*ApplicationsApi* | [**replace_application_sign_in_experience**](docs/ApplicationsApi.md#replace_application_sign_in_experience) | **PUT** /api/applications/{applicationId}/sign-in-experience | Update application level sign-in experience
*ApplicationsApi* | [**replace_application_user_consent_organizations**](docs/ApplicationsApi.md#replace_application_user_consent_organizations) | **PUT** /api/applications/{id}/users/{userId}/consent-organizations | Grant a list of organization access of a user for a application.
*ApplicationsApi* | [**update_application**](docs/ApplicationsApi.md#update_application) | **PATCH** /api/applications/{id} | Update application
*AuditLogsApi* | [**get_log**](docs/AuditLogsApi.md#get_log) | **GET** /api/logs/{id} | Get log
*AuditLogsApi* | [**list_logs**](docs/AuditLogsApi.md#list_logs) | **GET** /api/logs | Get logs
*AuthnApi* | [**assert_saml**](docs/AuthnApi.md#assert_saml) | **POST** /api/authn/saml/{connectorId} | SAML ACS endpoint (social)
*AuthnApi* | [**assert_single_sign_on_saml**](docs/AuthnApi.md#assert_single_sign_on_saml) | **POST** /api/authn/single-sign-on/saml/{connectorId} | SAML ACS endpoint (SSO)
*AuthnApi* | [**get_hasura_auth**](docs/AuthnApi.md#get_hasura_auth) | **GET** /api/authn/hasura | Hasura auth hook endpoint
*ConfigsApi* | [**delete_jwt_customizer**](docs/ConfigsApi.md#delete_jwt_customizer) | **DELETE** /api/configs/jwt-customizer/{tokenTypePath} | Delete JWT customizer
*ConfigsApi* | [**delete_oidc_key**](docs/ConfigsApi.md#delete_oidc_key) | **DELETE** /api/configs/oidc/{keyType}/{keyId} | Delete OIDC key
*ConfigsApi* | [**get_admin_console_config**](docs/ConfigsApi.md#get_admin_console_config) | **GET** /api/configs/admin-console | Get admin console config
*ConfigsApi* | [**get_jwt_customizer**](docs/ConfigsApi.md#get_jwt_customizer) | **GET** /api/configs/jwt-customizer/{tokenTypePath} | Get JWT customizer
*ConfigsApi* | [**get_oidc_keys**](docs/ConfigsApi.md#get_oidc_keys) | **GET** /api/configs/oidc/{keyType} | Get OIDC keys
*ConfigsApi* | [**list_jwt_customizers**](docs/ConfigsApi.md#list_jwt_customizers) | **GET** /api/configs/jwt-customizer | Get all JWT customizers
*ConfigsApi* | [**rotate_oidc_keys**](docs/ConfigsApi.md#rotate_oidc_keys) | **POST** /api/configs/oidc/{keyType}/rotate | Rotate OIDC keys
*ConfigsApi* | [**test_jwt_customizer**](docs/ConfigsApi.md#test_jwt_customizer) | **POST** /api/configs/jwt-customizer/test | Test JWT customizer
*ConfigsApi* | [**update_admin_console_config**](docs/ConfigsApi.md#update_admin_console_config) | **PATCH** /api/configs/admin-console | Update admin console config
*ConfigsApi* | [**update_jwt_customizer**](docs/ConfigsApi.md#update_jwt_customizer) | **PATCH** /api/configs/jwt-customizer/{tokenTypePath} | Update JWT customizer
*ConfigsApi* | [**upsert_jwt_customizer**](docs/ConfigsApi.md#upsert_jwt_customizer) | **PUT** /api/configs/jwt-customizer/{tokenTypePath} | Create or update JWT customizer
*ConnectorFactoriesApi* | [**get_connector_factory**](docs/ConnectorFactoriesApi.md#get_connector_factory) | **GET** /api/connector-factories/{id} | Get connector factory
*ConnectorFactoriesApi* | [**list_connector_factories**](docs/ConnectorFactoriesApi.md#list_connector_factories) | **GET** /api/connector-factories | Get connector factories
*ConnectorsApi* | [**create_connector**](docs/ConnectorsApi.md#create_connector) | **POST** /api/connectors | Create connector
*ConnectorsApi* | [**create_connector_authorization_uri**](docs/ConnectorsApi.md#create_connector_authorization_uri) | **POST** /api/connectors/{connectorId}/authorization-uri | Get connector&#39;s authorization URI
*ConnectorsApi* | [**create_connector_test**](docs/ConnectorsApi.md#create_connector_test) | **POST** /api/connectors/{factoryId}/test | Test passwordless connector
*ConnectorsApi* | [**delete_connector**](docs/ConnectorsApi.md#delete_connector) | **DELETE** /api/connectors/{id} | Delete connector
*ConnectorsApi* | [**get_connector**](docs/ConnectorsApi.md#get_connector) | **GET** /api/connectors/{id} | Get connector
*ConnectorsApi* | [**list_connectors**](docs/ConnectorsApi.md#list_connectors) | **GET** /api/connectors | Get connectors
*ConnectorsApi* | [**update_connector**](docs/ConnectorsApi.md#update_connector) | **PATCH** /api/connectors/{id} | Update connector
*CustomPhrasesApi* | [**delete_custom_phrase**](docs/CustomPhrasesApi.md#delete_custom_phrase) | **DELETE** /api/custom-phrases/{languageTag} | Delete custom phrase
*CustomPhrasesApi* | [**get_custom_phrase**](docs/CustomPhrasesApi.md#get_custom_phrase) | **GET** /api/custom-phrases/{languageTag} | Get custom phrases
*CustomPhrasesApi* | [**list_custom_phrases**](docs/CustomPhrasesApi.md#list_custom_phrases) | **GET** /api/custom-phrases | Get all custom phrases
*CustomPhrasesApi* | [**replace_custom_phrase**](docs/CustomPhrasesApi.md#replace_custom_phrase) | **PUT** /api/custom-phrases/{languageTag} | Upsert custom phrases
*DashboardApi* | [**get_active_user_counts**](docs/DashboardApi.md#get_active_user_counts) | **GET** /api/dashboard/users/active | Get active user data
*DashboardApi* | [**get_new_user_counts**](docs/DashboardApi.md#get_new_user_counts) | **GET** /api/dashboard/users/new | Get new user count
*DashboardApi* | [**get_total_user_count**](docs/DashboardApi.md#get_total_user_count) | **GET** /api/dashboard/users/total | Get total user count
*DomainsApi* | [**create_domain**](docs/DomainsApi.md#create_domain) | **POST** /api/domains | Create domain
*DomainsApi* | [**delete_domain**](docs/DomainsApi.md#delete_domain) | **DELETE** /api/domains/{id} | Delete domain
*DomainsApi* | [**get_domain**](docs/DomainsApi.md#get_domain) | **GET** /api/domains/{id} | Get domain
*DomainsApi* | [**list_domains**](docs/DomainsApi.md#list_domains) | **GET** /api/domains | Get domains
*HooksApi* | [**create_hook**](docs/HooksApi.md#create_hook) | **POST** /api/hooks | Create a hook
*HooksApi* | [**create_hook_test**](docs/HooksApi.md#create_hook_test) | **POST** /api/hooks/{id}/test | Test hook
*HooksApi* | [**delete_hook**](docs/HooksApi.md#delete_hook) | **DELETE** /api/hooks/{id} | Delete hook
*HooksApi* | [**get_hook**](docs/HooksApi.md#get_hook) | **GET** /api/hooks/{id} | Get hook
*HooksApi* | [**list_hook_recent_logs**](docs/HooksApi.md#list_hook_recent_logs) | **GET** /api/hooks/{id}/recent-logs | Get recent logs for a hook
*HooksApi* | [**list_hooks**](docs/HooksApi.md#list_hooks) | **GET** /api/hooks | Get hooks
*HooksApi* | [**update_hook**](docs/HooksApi.md#update_hook) | **PATCH** /api/hooks/{id} | Update hook
*HooksApi* | [**update_hook_signing_key**](docs/HooksApi.md#update_hook_signing_key) | **PATCH** /api/hooks/{id}/signing-key | Update signing key for a hook
*InteractionApi* | [**api_interaction_bind_mfa_post**](docs/InteractionApi.md#api_interaction_bind_mfa_post) | **POST** /api/interaction/bind-mfa | 
*InteractionApi* | [**api_interaction_consent_get**](docs/InteractionApi.md#api_interaction_consent_get) | **GET** /api/interaction/consent | 
*InteractionApi* | [**api_interaction_consent_post**](docs/InteractionApi.md#api_interaction_consent_post) | **POST** /api/interaction/consent | 
*InteractionApi* | [**api_interaction_delete**](docs/InteractionApi.md#api_interaction_delete) | **DELETE** /api/interaction | 
*InteractionApi* | [**api_interaction_event_put**](docs/InteractionApi.md#api_interaction_event_put) | **PUT** /api/interaction/event | 
*InteractionApi* | [**api_interaction_identifiers_patch**](docs/InteractionApi.md#api_interaction_identifiers_patch) | **PATCH** /api/interaction/identifiers | 
*InteractionApi* | [**api_interaction_mfa_put**](docs/InteractionApi.md#api_interaction_mfa_put) | **PUT** /api/interaction/mfa | 
*InteractionApi* | [**api_interaction_mfa_skipped_put**](docs/InteractionApi.md#api_interaction_mfa_skipped_put) | **PUT** /api/interaction/mfa-skipped | 
*InteractionApi* | [**api_interaction_profile_delete**](docs/InteractionApi.md#api_interaction_profile_delete) | **DELETE** /api/interaction/profile | 
*InteractionApi* | [**api_interaction_profile_patch**](docs/InteractionApi.md#api_interaction_profile_patch) | **PATCH** /api/interaction/profile | 
*InteractionApi* | [**api_interaction_profile_put**](docs/InteractionApi.md#api_interaction_profile_put) | **PUT** /api/interaction/profile | 
*InteractionApi* | [**api_interaction_put**](docs/InteractionApi.md#api_interaction_put) | **PUT** /api/interaction | 
*InteractionApi* | [**api_interaction_single_sign_on_connector_id_authentication_post**](docs/InteractionApi.md#api_interaction_single_sign_on_connector_id_authentication_post) | **POST** /api/interaction/single-sign-on/{connectorId}/authentication | 
*InteractionApi* | [**api_interaction_single_sign_on_connector_id_authorization_url_post**](docs/InteractionApi.md#api_interaction_single_sign_on_connector_id_authorization_url_post) | **POST** /api/interaction/single-sign-on/{connectorId}/authorization-url | 
*InteractionApi* | [**api_interaction_single_sign_on_connector_id_registration_post**](docs/InteractionApi.md#api_interaction_single_sign_on_connector_id_registration_post) | **POST** /api/interaction/single-sign-on/{connectorId}/registration | 
*InteractionApi* | [**api_interaction_single_sign_on_connectors_get**](docs/InteractionApi.md#api_interaction_single_sign_on_connectors_get) | **GET** /api/interaction/single-sign-on/connectors | 
*InteractionApi* | [**api_interaction_submit_post**](docs/InteractionApi.md#api_interaction_submit_post) | **POST** /api/interaction/submit | 
*InteractionApi* | [**api_interaction_verification_social_authorization_uri_post**](docs/InteractionApi.md#api_interaction_verification_social_authorization_uri_post) | **POST** /api/interaction/verification/social-authorization-uri | 
*InteractionApi* | [**api_interaction_verification_totp_post**](docs/InteractionApi.md#api_interaction_verification_totp_post) | **POST** /api/interaction/verification/totp | 
*InteractionApi* | [**api_interaction_verification_verification_code_post**](docs/InteractionApi.md#api_interaction_verification_verification_code_post) | **POST** /api/interaction/verification/verification-code | 
*InteractionApi* | [**api_interaction_verification_webauthn_authentication_post**](docs/InteractionApi.md#api_interaction_verification_webauthn_authentication_post) | **POST** /api/interaction/verification/webauthn-authentication | 
*InteractionApi* | [**api_interaction_verification_webauthn_registration_post**](docs/InteractionApi.md#api_interaction_verification_webauthn_registration_post) | **POST** /api/interaction/verification/webauthn-registration | 
*OrganizationInvitationsApi* | [**create_organization_invitation**](docs/OrganizationInvitationsApi.md#create_organization_invitation) | **POST** /api/organization-invitations | Create organization invitation
*OrganizationInvitationsApi* | [**create_organization_invitation_message**](docs/OrganizationInvitationsApi.md#create_organization_invitation_message) | **POST** /api/organization-invitations/{id}/message | Resend invitation message
*OrganizationInvitationsApi* | [**delete_organization_invitation**](docs/OrganizationInvitationsApi.md#delete_organization_invitation) | **DELETE** /api/organization-invitations/{id} | Delete organization invitation
*OrganizationInvitationsApi* | [**get_organization_invitation**](docs/OrganizationInvitationsApi.md#get_organization_invitation) | **GET** /api/organization-invitations/{id} | Get organization invitation
*OrganizationInvitationsApi* | [**list_organization_invitations**](docs/OrganizationInvitationsApi.md#list_organization_invitations) | **GET** /api/organization-invitations | Get organization invitations
*OrganizationInvitationsApi* | [**replace_organization_invitation_status**](docs/OrganizationInvitationsApi.md#replace_organization_invitation_status) | **PUT** /api/organization-invitations/{id}/status | Update organization invitation status
*OrganizationRolesApi* | [**create_organization_role**](docs/OrganizationRolesApi.md#create_organization_role) | **POST** /api/organization-roles | Create an organization role
*OrganizationRolesApi* | [**create_organization_role_resource_scope**](docs/OrganizationRolesApi.md#create_organization_role_resource_scope) | **POST** /api/organization-roles/{id}/resource-scopes | Assign resource scopes to organization role
*OrganizationRolesApi* | [**create_organization_role_scope**](docs/OrganizationRolesApi.md#create_organization_role_scope) | **POST** /api/organization-roles/{id}/scopes | Assign organization scopes to organization role
*OrganizationRolesApi* | [**delete_organization_role**](docs/OrganizationRolesApi.md#delete_organization_role) | **DELETE** /api/organization-roles/{id} | Delete organization role
*OrganizationRolesApi* | [**delete_organization_role_resource_scope**](docs/OrganizationRolesApi.md#delete_organization_role_resource_scope) | **DELETE** /api/organization-roles/{id}/resource-scopes/{scopeId} | Remove resource scope
*OrganizationRolesApi* | [**delete_organization_role_scope**](docs/OrganizationRolesApi.md#delete_organization_role_scope) | **DELETE** /api/organization-roles/{id}/scopes/{organizationScopeId} | Remove organization scope
*OrganizationRolesApi* | [**get_organization_role**](docs/OrganizationRolesApi.md#get_organization_role) | **GET** /api/organization-roles/{id} | Get organization role
*OrganizationRolesApi* | [**list_organization_role_resource_scopes**](docs/OrganizationRolesApi.md#list_organization_role_resource_scopes) | **GET** /api/organization-roles/{id}/resource-scopes | Get organization role resource scopes
*OrganizationRolesApi* | [**list_organization_role_scopes**](docs/OrganizationRolesApi.md#list_organization_role_scopes) | **GET** /api/organization-roles/{id}/scopes | Get organization role scopes
*OrganizationRolesApi* | [**list_organization_roles**](docs/OrganizationRolesApi.md#list_organization_roles) | **GET** /api/organization-roles | Get organization roles
*OrganizationRolesApi* | [**replace_organization_role_resource_scopes**](docs/OrganizationRolesApi.md#replace_organization_role_resource_scopes) | **PUT** /api/organization-roles/{id}/resource-scopes | Replace resource scopes for organization role
*OrganizationRolesApi* | [**replace_organization_role_scopes**](docs/OrganizationRolesApi.md#replace_organization_role_scopes) | **PUT** /api/organization-roles/{id}/scopes | Replace organization scopes for organization role
*OrganizationRolesApi* | [**update_organization_role**](docs/OrganizationRolesApi.md#update_organization_role) | **PATCH** /api/organization-roles/{id} | Update organization role
*OrganizationScopesApi* | [**create_organization_scope**](docs/OrganizationScopesApi.md#create_organization_scope) | **POST** /api/organization-scopes | Create an organization scope
*OrganizationScopesApi* | [**delete_organization_scope**](docs/OrganizationScopesApi.md#delete_organization_scope) | **DELETE** /api/organization-scopes/{id} | Delete organization scope
*OrganizationScopesApi* | [**get_organization_scope**](docs/OrganizationScopesApi.md#get_organization_scope) | **GET** /api/organization-scopes/{id} | Get organization scope
*OrganizationScopesApi* | [**list_organization_scopes**](docs/OrganizationScopesApi.md#list_organization_scopes) | **GET** /api/organization-scopes | Get organization scopes
*OrganizationScopesApi* | [**update_organization_scope**](docs/OrganizationScopesApi.md#update_organization_scope) | **PATCH** /api/organization-scopes/{id} | Update organization scope
*OrganizationsApi* | [**add_organization_applications**](docs/OrganizationsApi.md#add_organization_applications) | **POST** /api/organizations/{id}/applications | Add organization application
*OrganizationsApi* | [**add_organization_users**](docs/OrganizationsApi.md#add_organization_users) | **POST** /api/organizations/{id}/users | Add user members to organization
*OrganizationsApi* | [**assign_organization_roles_to_application**](docs/OrganizationsApi.md#assign_organization_roles_to_application) | **POST** /api/organizations/{id}/applications/{applicationId}/roles | Add organization application role
*OrganizationsApi* | [**assign_organization_roles_to_applications**](docs/OrganizationsApi.md#assign_organization_roles_to_applications) | **POST** /api/organizations/{id}/applications/roles | Assign roles to applications in an organization
*OrganizationsApi* | [**assign_organization_roles_to_user**](docs/OrganizationsApi.md#assign_organization_roles_to_user) | **POST** /api/organizations/{id}/users/{userId}/roles | Assign roles to a user in an organization
*OrganizationsApi* | [**assign_organization_roles_to_users**](docs/OrganizationsApi.md#assign_organization_roles_to_users) | **POST** /api/organizations/{id}/users/roles | Assign roles to organization user members
*OrganizationsApi* | [**create_organization**](docs/OrganizationsApi.md#create_organization) | **POST** /api/organizations | Create an organization
*OrganizationsApi* | [**create_organization_jit_email_domain**](docs/OrganizationsApi.md#create_organization_jit_email_domain) | **POST** /api/organizations/{id}/jit/email-domains | Add organization JIT email domain
*OrganizationsApi* | [**create_organization_jit_role**](docs/OrganizationsApi.md#create_organization_jit_role) | **POST** /api/organizations/{id}/jit/roles | Add organization JIT default roles
*OrganizationsApi* | [**create_organization_jit_sso_connector**](docs/OrganizationsApi.md#create_organization_jit_sso_connector) | **POST** /api/organizations/{id}/jit/sso-connectors | Add organization JIT SSO connectors
*OrganizationsApi* | [**delete_organization**](docs/OrganizationsApi.md#delete_organization) | **DELETE** /api/organizations/{id} | Delete organization
*OrganizationsApi* | [**delete_organization_application**](docs/OrganizationsApi.md#delete_organization_application) | **DELETE** /api/organizations/{id}/applications/{applicationId} | Remove organization application
*OrganizationsApi* | [**delete_organization_application_role**](docs/OrganizationsApi.md#delete_organization_application_role) | **DELETE** /api/organizations/{id}/applications/{applicationId}/roles/{organizationRoleId} | Remove organization application role
*OrganizationsApi* | [**delete_organization_jit_email_domain**](docs/OrganizationsApi.md#delete_organization_jit_email_domain) | **DELETE** /api/organizations/{id}/jit/email-domains/{emailDomain} | Remove organization JIT email domain
*OrganizationsApi* | [**delete_organization_jit_role**](docs/OrganizationsApi.md#delete_organization_jit_role) | **DELETE** /api/organizations/{id}/jit/roles/{organizationRoleId} | Remove organization JIT default role
*OrganizationsApi* | [**delete_organization_jit_sso_connector**](docs/OrganizationsApi.md#delete_organization_jit_sso_connector) | **DELETE** /api/organizations/{id}/jit/sso-connectors/{ssoConnectorId} | Remove organization JIT SSO connector
*OrganizationsApi* | [**delete_organization_user**](docs/OrganizationsApi.md#delete_organization_user) | **DELETE** /api/organizations/{id}/users/{userId} | Remove user member from organization
*OrganizationsApi* | [**delete_organization_user_role**](docs/OrganizationsApi.md#delete_organization_user_role) | **DELETE** /api/organizations/{id}/users/{userId}/roles/{organizationRoleId} | Remove a role from a user in an organization
*OrganizationsApi* | [**get_organization**](docs/OrganizationsApi.md#get_organization) | **GET** /api/organizations/{id} | Get organization
*OrganizationsApi* | [**list_organization_application_roles**](docs/OrganizationsApi.md#list_organization_application_roles) | **GET** /api/organizations/{id}/applications/{applicationId}/roles | Get organization application roles
*OrganizationsApi* | [**list_organization_applications**](docs/OrganizationsApi.md#list_organization_applications) | **GET** /api/organizations/{id}/applications | Get organization applications
*OrganizationsApi* | [**list_organization_jit_email_domains**](docs/OrganizationsApi.md#list_organization_jit_email_domains) | **GET** /api/organizations/{id}/jit/email-domains | Get organization JIT email domains
*OrganizationsApi* | [**list_organization_jit_roles**](docs/OrganizationsApi.md#list_organization_jit_roles) | **GET** /api/organizations/{id}/jit/roles | Get organization JIT default roles
*OrganizationsApi* | [**list_organization_jit_sso_connectors**](docs/OrganizationsApi.md#list_organization_jit_sso_connectors) | **GET** /api/organizations/{id}/jit/sso-connectors | Get organization JIT SSO connectors
*OrganizationsApi* | [**list_organization_user_roles**](docs/OrganizationsApi.md#list_organization_user_roles) | **GET** /api/organizations/{id}/users/{userId}/roles | Get roles for a user in an organization
*OrganizationsApi* | [**list_organization_user_scopes**](docs/OrganizationsApi.md#list_organization_user_scopes) | **GET** /api/organizations/{id}/users/{userId}/scopes | Get scopes for a user in an organization tailored by the organization roles
*OrganizationsApi* | [**list_organization_users**](docs/OrganizationsApi.md#list_organization_users) | **GET** /api/organizations/{id}/users | Get organization user members
*OrganizationsApi* | [**list_organizations**](docs/OrganizationsApi.md#list_organizations) | **GET** /api/organizations | Get organizations
*OrganizationsApi* | [**replace_organization_application_roles**](docs/OrganizationsApi.md#replace_organization_application_roles) | **PUT** /api/organizations/{id}/applications/{applicationId}/roles | Replace organization application roles
*OrganizationsApi* | [**replace_organization_applications**](docs/OrganizationsApi.md#replace_organization_applications) | **PUT** /api/organizations/{id}/applications | Replace organization applications
*OrganizationsApi* | [**replace_organization_jit_email_domains**](docs/OrganizationsApi.md#replace_organization_jit_email_domains) | **PUT** /api/organizations/{id}/jit/email-domains | Replace organization JIT email domains
*OrganizationsApi* | [**replace_organization_jit_roles**](docs/OrganizationsApi.md#replace_organization_jit_roles) | **PUT** /api/organizations/{id}/jit/roles | Replace organization JIT default roles
*OrganizationsApi* | [**replace_organization_jit_sso_connectors**](docs/OrganizationsApi.md#replace_organization_jit_sso_connectors) | **PUT** /api/organizations/{id}/jit/sso-connectors | Replace organization JIT SSO connectors
*OrganizationsApi* | [**replace_organization_user_roles**](docs/OrganizationsApi.md#replace_organization_user_roles) | **PUT** /api/organizations/{id}/users/{userId}/roles | Update roles for a user in an organization
*OrganizationsApi* | [**replace_organization_users**](docs/OrganizationsApi.md#replace_organization_users) | **PUT** /api/organizations/{id}/users | Replace organization user members
*OrganizationsApi* | [**update_organization**](docs/OrganizationsApi.md#update_organization) | **PATCH** /api/organizations/{id} | Update organization
*ResourcesApi* | [**create_resource**](docs/ResourcesApi.md#create_resource) | **POST** /api/resources | Create an API resource
*ResourcesApi* | [**create_resource_scope**](docs/ResourcesApi.md#create_resource_scope) | **POST** /api/resources/{resourceId}/scopes | Create API resource scope
*ResourcesApi* | [**delete_resource**](docs/ResourcesApi.md#delete_resource) | **DELETE** /api/resources/{id} | Delete API resource
*ResourcesApi* | [**delete_resource_scope**](docs/ResourcesApi.md#delete_resource_scope) | **DELETE** /api/resources/{resourceId}/scopes/{scopeId} | Delete API resource scope
*ResourcesApi* | [**get_resource**](docs/ResourcesApi.md#get_resource) | **GET** /api/resources/{id} | Get API resource
*ResourcesApi* | [**list_resource_scopes**](docs/ResourcesApi.md#list_resource_scopes) | **GET** /api/resources/{resourceId}/scopes | Get API resource scopes
*ResourcesApi* | [**list_resources**](docs/ResourcesApi.md#list_resources) | **GET** /api/resources | Get API resources
*ResourcesApi* | [**update_resource**](docs/ResourcesApi.md#update_resource) | **PATCH** /api/resources/{id} | Update API resource
*ResourcesApi* | [**update_resource_is_default**](docs/ResourcesApi.md#update_resource_is_default) | **PATCH** /api/resources/{id}/is-default | Set API resource as default
*ResourcesApi* | [**update_resource_scope**](docs/ResourcesApi.md#update_resource_scope) | **PATCH** /api/resources/{resourceId}/scopes/{scopeId} | Update API resource scope
*RolesApi* | [**create_role**](docs/RolesApi.md#create_role) | **POST** /api/roles | Create a role
*RolesApi* | [**create_role_application**](docs/RolesApi.md#create_role_application) | **POST** /api/roles/{id}/applications | Assign role to applications
*RolesApi* | [**create_role_scope**](docs/RolesApi.md#create_role_scope) | **POST** /api/roles/{id}/scopes | Link scopes to role
*RolesApi* | [**create_role_user**](docs/RolesApi.md#create_role_user) | **POST** /api/roles/{id}/users | Assign role to users
*RolesApi* | [**delete_role**](docs/RolesApi.md#delete_role) | **DELETE** /api/roles/{id} | Delete role
*RolesApi* | [**delete_role_application**](docs/RolesApi.md#delete_role_application) | **DELETE** /api/roles/{id}/applications/{applicationId} | Remove role from application
*RolesApi* | [**delete_role_scope**](docs/RolesApi.md#delete_role_scope) | **DELETE** /api/roles/{id}/scopes/{scopeId} | Unlink scope from role
*RolesApi* | [**delete_role_user**](docs/RolesApi.md#delete_role_user) | **DELETE** /api/roles/{id}/users/{userId} | Remove role from user
*RolesApi* | [**get_role**](docs/RolesApi.md#get_role) | **GET** /api/roles/{id} | Get role
*RolesApi* | [**list_role_applications**](docs/RolesApi.md#list_role_applications) | **GET** /api/roles/{id}/applications | Get role applications
*RolesApi* | [**list_role_scopes**](docs/RolesApi.md#list_role_scopes) | **GET** /api/roles/{id}/scopes | Get role scopes
*RolesApi* | [**list_role_users**](docs/RolesApi.md#list_role_users) | **GET** /api/roles/{id}/users | Get role users
*RolesApi* | [**list_roles**](docs/RolesApi.md#list_roles) | **GET** /api/roles | Get roles
*RolesApi* | [**update_role**](docs/RolesApi.md#update_role) | **PATCH** /api/roles/{id} | Update role
*SSOConnectorProvidersApi* | [**list_sso_connector_providers**](docs/SSOConnectorProvidersApi.md#list_sso_connector_providers) | **GET** /api/sso-connector-providers | List all the supported SSO connector provider details
*SSOConnectorsApi* | [**create_sso_connector**](docs/SSOConnectorsApi.md#create_sso_connector) | **POST** /api/sso-connectors | Create SSO connector
*SSOConnectorsApi* | [**delete_sso_connector**](docs/SSOConnectorsApi.md#delete_sso_connector) | **DELETE** /api/sso-connectors/{id} | Delete SSO connector
*SSOConnectorsApi* | [**get_sso_connector**](docs/SSOConnectorsApi.md#get_sso_connector) | **GET** /api/sso-connectors/{id} | Get SSO connector
*SSOConnectorsApi* | [**list_sso_connectors**](docs/SSOConnectorsApi.md#list_sso_connectors) | **GET** /api/sso-connectors | List SSO connectors
*SSOConnectorsApi* | [**update_sso_connector**](docs/SSOConnectorsApi.md#update_sso_connector) | **PATCH** /api/sso-connectors/{id} | Update SSO connector
*SignInExperienceApi* | [**get_sign_in_exp**](docs/SignInExperienceApi.md#get_sign_in_exp) | **GET** /api/sign-in-exp | Get default sign-in experience settings
*SignInExperienceApi* | [**update_sign_in_exp**](docs/SignInExperienceApi.md#update_sign_in_exp) | **PATCH** /api/sign-in-exp | Update default sign-in experience settings
*StatusApi* | [**get_status**](docs/StatusApi.md#get_status) | **GET** /api/status | Health check
*SwaggerJsonApi* | [**get_swagger_json**](docs/SwaggerJsonApi.md#get_swagger_json) | **GET** /api/swagger.json | Get Swagger JSON
*SystemsApi* | [**get_system_application_config**](docs/SystemsApi.md#get_system_application_config) | **GET** /api/systems/application | Get the application constants.
*UserAssetsApi* | [**create_user_asset**](docs/UserAssetsApi.md#create_user_asset) | **POST** /api/user-assets | Upload asset
*UserAssetsApi* | [**get_user_asset_service_status**](docs/UserAssetsApi.md#get_user_asset_service_status) | **GET** /api/user-assets/service-status | Get service status
*UsersApi* | [**assign_user_roles**](docs/UsersApi.md#assign_user_roles) | **POST** /api/users/{userId}/roles | Assign roles to user
*UsersApi* | [**create_user**](docs/UsersApi.md#create_user) | **POST** /api/users | Create user
*UsersApi* | [**create_user_identity**](docs/UsersApi.md#create_user_identity) | **POST** /api/users/{userId}/identities | Link social identity to user
*UsersApi* | [**create_user_mfa_verification**](docs/UsersApi.md#create_user_mfa_verification) | **POST** /api/users/{userId}/mfa-verifications | Create an MFA verification for a user
*UsersApi* | [**delete_user**](docs/UsersApi.md#delete_user) | **DELETE** /api/users/{userId} | Delete user
*UsersApi* | [**delete_user_identity**](docs/UsersApi.md#delete_user_identity) | **DELETE** /api/users/{userId}/identities/{target} | Delete social identity from user
*UsersApi* | [**delete_user_mfa_verification**](docs/UsersApi.md#delete_user_mfa_verification) | **DELETE** /api/users/{userId}/mfa-verifications/{verificationId} | Delete an MFA verification for a user
*UsersApi* | [**delete_user_role**](docs/UsersApi.md#delete_user_role) | **DELETE** /api/users/{userId}/roles/{roleId} | Remove role from user
*UsersApi* | [**get_user**](docs/UsersApi.md#get_user) | **GET** /api/users/{userId} | Get user
*UsersApi* | [**get_user_has_password**](docs/UsersApi.md#get_user_has_password) | **GET** /api/users/{userId}/has-password | Check if user has password
*UsersApi* | [**list_user_custom_data**](docs/UsersApi.md#list_user_custom_data) | **GET** /api/users/{userId}/custom-data | Get user custom data
*UsersApi* | [**list_user_mfa_verifications**](docs/UsersApi.md#list_user_mfa_verifications) | **GET** /api/users/{userId}/mfa-verifications | Get user&#39;s MFA verifications
*UsersApi* | [**list_user_organizations**](docs/UsersApi.md#list_user_organizations) | **GET** /api/users/{userId}/organizations | Get organizations for a user
*UsersApi* | [**list_user_roles**](docs/UsersApi.md#list_user_roles) | **GET** /api/users/{userId}/roles | Get roles for user
*UsersApi* | [**list_users**](docs/UsersApi.md#list_users) | **GET** /api/users | Get users
*UsersApi* | [**replace_user_identity**](docs/UsersApi.md#replace_user_identity) | **PUT** /api/users/{userId}/identities/{target} | Update social identity of user
*UsersApi* | [**replace_user_roles**](docs/UsersApi.md#replace_user_roles) | **PUT** /api/users/{userId}/roles | Update roles for user
*UsersApi* | [**update_user**](docs/UsersApi.md#update_user) | **PATCH** /api/users/{userId} | Update user
*UsersApi* | [**update_user_custom_data**](docs/UsersApi.md#update_user_custom_data) | **PATCH** /api/users/{userId}/custom-data | Update user custom data
*UsersApi* | [**update_user_is_suspended**](docs/UsersApi.md#update_user_is_suspended) | **PATCH** /api/users/{userId}/is-suspended | Update user suspension status
*UsersApi* | [**update_user_password**](docs/UsersApi.md#update_user_password) | **PATCH** /api/users/{userId}/password | Update user password
*UsersApi* | [**update_user_profile**](docs/UsersApi.md#update_user_profile) | **PATCH** /api/users/{userId}/profile | Update user profile
*UsersApi* | [**verify_user_password**](docs/UsersApi.md#verify_user_password) | **POST** /api/users/{userId}/password/verify | Verify user password
*VerificationCodesApi* | [**create_verification_code**](docs/VerificationCodesApi.md#create_verification_code) | **POST** /api/verification-codes | Request and send a verification code
*VerificationCodesApi* | [**verify_verification_code**](docs/VerificationCodesApi.md#verify_verification_code) | **POST** /api/verification-codes/verify | Verify a verification code
*WellKnownApi* | [**get_sign_in_experience_config**](docs/WellKnownApi.md#get_sign_in_experience_config) | **GET** /api/.well-known/sign-in-exp | Get full sign-in experience
*WellKnownApi* | [**get_sign_in_experience_phrases**](docs/WellKnownApi.md#get_sign_in_experience_phrases) | **GET** /api/.well-known/phrases | Get localized phrases


## Documentation For Models

 - [AddOrganizationApplicationsRequest](docs/AddOrganizationApplicationsRequest.md)
 - [AddOrganizationUsersRequest](docs/AddOrganizationUsersRequest.md)
 - [ApiInteractionBindMfaPostRequest](docs/ApiInteractionBindMfaPostRequest.md)
 - [ApiInteractionBindMfaPostRequestOneOf](docs/ApiInteractionBindMfaPostRequestOneOf.md)
 - [ApiInteractionBindMfaPostRequestOneOf1](docs/ApiInteractionBindMfaPostRequestOneOf1.md)
 - [ApiInteractionBindMfaPostRequestOneOf1ClientExtensionResults](docs/ApiInteractionBindMfaPostRequestOneOf1ClientExtensionResults.md)
 - [ApiInteractionBindMfaPostRequestOneOf1ClientExtensionResultsCrepProps](docs/ApiInteractionBindMfaPostRequestOneOf1ClientExtensionResultsCrepProps.md)
 - [ApiInteractionBindMfaPostRequestOneOf1Response](docs/ApiInteractionBindMfaPostRequestOneOf1Response.md)
 - [ApiInteractionBindMfaPostRequestOneOf2](docs/ApiInteractionBindMfaPostRequestOneOf2.md)
 - [ApiInteractionConsentGet200Response](docs/ApiInteractionConsentGet200Response.md)
 - [ApiInteractionConsentGet200ResponseApplication](docs/ApiInteractionConsentGet200ResponseApplication.md)
 - [ApiInteractionConsentGet200ResponseApplicationBranding](docs/ApiInteractionConsentGet200ResponseApplicationBranding.md)
 - [ApiInteractionConsentGet200ResponseOrganizationsInner](docs/ApiInteractionConsentGet200ResponseOrganizationsInner.md)
 - [ApiInteractionConsentGet200ResponseOrganizationsInnerMissingResourceScopesInner](docs/ApiInteractionConsentGet200ResponseOrganizationsInnerMissingResourceScopesInner.md)
 - [ApiInteractionConsentGet200ResponseOrganizationsInnerMissingResourceScopesInnerResource](docs/ApiInteractionConsentGet200ResponseOrganizationsInnerMissingResourceScopesInnerResource.md)
 - [ApiInteractionConsentGet200ResponseOrganizationsInnerMissingResourceScopesInnerScopesInner](docs/ApiInteractionConsentGet200ResponseOrganizationsInnerMissingResourceScopesInnerScopesInner.md)
 - [ApiInteractionConsentGet200ResponseUser](docs/ApiInteractionConsentGet200ResponseUser.md)
 - [ApiInteractionConsentPostRequest](docs/ApiInteractionConsentPostRequest.md)
 - [ApiInteractionEventPutRequest](docs/ApiInteractionEventPutRequest.md)
 - [ApiInteractionMfaPutRequest](docs/ApiInteractionMfaPutRequest.md)
 - [ApiInteractionMfaPutRequestOneOf](docs/ApiInteractionMfaPutRequestOneOf.md)
 - [ApiInteractionMfaPutRequestOneOf1](docs/ApiInteractionMfaPutRequestOneOf1.md)
 - [ApiInteractionMfaPutRequestOneOfResponse](docs/ApiInteractionMfaPutRequestOneOfResponse.md)
 - [ApiInteractionMfaSkippedPutRequest](docs/ApiInteractionMfaSkippedPutRequest.md)
 - [ApiInteractionPutRequest](docs/ApiInteractionPutRequest.md)
 - [ApiInteractionPutRequestIdentifier](docs/ApiInteractionPutRequestIdentifier.md)
 - [ApiInteractionPutRequestIdentifierOneOf](docs/ApiInteractionPutRequestIdentifierOneOf.md)
 - [ApiInteractionPutRequestIdentifierOneOf1](docs/ApiInteractionPutRequestIdentifierOneOf1.md)
 - [ApiInteractionPutRequestIdentifierOneOf2](docs/ApiInteractionPutRequestIdentifierOneOf2.md)
 - [ApiInteractionPutRequestIdentifierOneOf3](docs/ApiInteractionPutRequestIdentifierOneOf3.md)
 - [ApiInteractionPutRequestIdentifierOneOf4](docs/ApiInteractionPutRequestIdentifierOneOf4.md)
 - [ApiInteractionPutRequestIdentifierOneOf5](docs/ApiInteractionPutRequestIdentifierOneOf5.md)
 - [ApiInteractionPutRequestIdentifierOneOf6](docs/ApiInteractionPutRequestIdentifierOneOf6.md)
 - [ApiInteractionPutRequestIdentifierOneOf7](docs/ApiInteractionPutRequestIdentifierOneOf7.md)
 - [ApiInteractionPutRequestProfile](docs/ApiInteractionPutRequestProfile.md)
 - [ApiInteractionSingleSignOnConnectorIdAuthorizationUrlPostRequest](docs/ApiInteractionSingleSignOnConnectorIdAuthorizationUrlPostRequest.md)
 - [ApiInteractionSubmitPost200Response](docs/ApiInteractionSubmitPost200Response.md)
 - [ApiInteractionVerificationSocialAuthorizationUriPostRequest](docs/ApiInteractionVerificationSocialAuthorizationUriPostRequest.md)
 - [ApiInteractionVerificationTotpPost200Response](docs/ApiInteractionVerificationTotpPost200Response.md)
 - [ApiInteractionVerificationVerificationCodePostRequest](docs/ApiInteractionVerificationVerificationCodePostRequest.md)
 - [ApiInteractionVerificationVerificationCodePostRequestOneOf](docs/ApiInteractionVerificationVerificationCodePostRequestOneOf.md)
 - [ApiInteractionVerificationVerificationCodePostRequestOneOf1](docs/ApiInteractionVerificationVerificationCodePostRequestOneOf1.md)
 - [ApiInteractionVerificationWebauthnAuthenticationPost200Response](docs/ApiInteractionVerificationWebauthnAuthenticationPost200Response.md)
 - [ApiInteractionVerificationWebauthnRegistrationPost200Response](docs/ApiInteractionVerificationWebauthnRegistrationPost200Response.md)
 - [ApiInteractionVerificationWebauthnRegistrationPost200ResponseAuthenticatorSelection](docs/ApiInteractionVerificationWebauthnRegistrationPost200ResponseAuthenticatorSelection.md)
 - [ApiInteractionVerificationWebauthnRegistrationPost200ResponseExcludeCredentialsInner](docs/ApiInteractionVerificationWebauthnRegistrationPost200ResponseExcludeCredentialsInner.md)
 - [ApiInteractionVerificationWebauthnRegistrationPost200ResponseExtensions](docs/ApiInteractionVerificationWebauthnRegistrationPost200ResponseExtensions.md)
 - [ApiInteractionVerificationWebauthnRegistrationPost200ResponsePubKeyCredParamsInner](docs/ApiInteractionVerificationWebauthnRegistrationPost200ResponsePubKeyCredParamsInner.md)
 - [ApiInteractionVerificationWebauthnRegistrationPost200ResponseRp](docs/ApiInteractionVerificationWebauthnRegistrationPost200ResponseRp.md)
 - [ApiInteractionVerificationWebauthnRegistrationPost200ResponseUser](docs/ApiInteractionVerificationWebauthnRegistrationPost200ResponseUser.md)
 - [AssertSingleSignOnSamlRequest](docs/AssertSingleSignOnSamlRequest.md)
 - [AssignApplicationRolesRequest](docs/AssignApplicationRolesRequest.md)
 - [AssignOrganizationRolesToApplicationRequest](docs/AssignOrganizationRolesToApplicationRequest.md)
 - [AssignOrganizationRolesToApplicationsRequest](docs/AssignOrganizationRolesToApplicationsRequest.md)
 - [AssignOrganizationRolesToUserRequest](docs/AssignOrganizationRolesToUserRequest.md)
 - [AssignOrganizationRolesToUsersRequest](docs/AssignOrganizationRolesToUsersRequest.md)
 - [CreateApplicationProtectedAppMetadataCustomDomainRequest](docs/CreateApplicationProtectedAppMetadataCustomDomainRequest.md)
 - [CreateApplicationRequest](docs/CreateApplicationRequest.md)
 - [CreateApplicationRequestProtectedAppMetadata](docs/CreateApplicationRequestProtectedAppMetadata.md)
 - [CreateApplicationUserConsentOrganizationRequest](docs/CreateApplicationUserConsentOrganizationRequest.md)
 - [CreateApplicationUserConsentScopeRequest](docs/CreateApplicationUserConsentScopeRequest.md)
 - [CreateConnectorAuthorizationUri200Response](docs/CreateConnectorAuthorizationUri200Response.md)
 - [CreateConnectorAuthorizationUriRequest](docs/CreateConnectorAuthorizationUriRequest.md)
 - [CreateConnectorRequest](docs/CreateConnectorRequest.md)
 - [CreateConnectorRequestMetadata](docs/CreateConnectorRequestMetadata.md)
 - [CreateConnectorTestRequest](docs/CreateConnectorTestRequest.md)
 - [CreateDomainRequest](docs/CreateDomainRequest.md)
 - [CreateHookRequest](docs/CreateHookRequest.md)
 - [CreateHookRequestConfig](docs/CreateHookRequestConfig.md)
 - [CreateHookTestRequest](docs/CreateHookTestRequest.md)
 - [CreateHookTestRequestConfig](docs/CreateHookTestRequestConfig.md)
 - [CreateOrganizationInvitationRequest](docs/CreateOrganizationInvitationRequest.md)
 - [CreateOrganizationInvitationRequestMessagePayload](docs/CreateOrganizationInvitationRequestMessagePayload.md)
 - [CreateOrganizationInvitationRequestMessagePayloadOneOf](docs/CreateOrganizationInvitationRequestMessagePayloadOneOf.md)
 - [CreateOrganizationJitEmailDomainRequest](docs/CreateOrganizationJitEmailDomainRequest.md)
 - [CreateOrganizationJitRoleRequest](docs/CreateOrganizationJitRoleRequest.md)
 - [CreateOrganizationJitSsoConnectorRequest](docs/CreateOrganizationJitSsoConnectorRequest.md)
 - [CreateOrganizationRequest](docs/CreateOrganizationRequest.md)
 - [CreateOrganizationRoleRequest](docs/CreateOrganizationRoleRequest.md)
 - [CreateOrganizationRoleResourceScopeRequest](docs/CreateOrganizationRoleResourceScopeRequest.md)
 - [CreateOrganizationRoleScopeRequest](docs/CreateOrganizationRoleScopeRequest.md)
 - [CreateOrganizationScopeRequest](docs/CreateOrganizationScopeRequest.md)
 - [CreateResourceRequest](docs/CreateResourceRequest.md)
 - [CreateResourceScopeRequest](docs/CreateResourceScopeRequest.md)
 - [CreateRoleApplicationRequest](docs/CreateRoleApplicationRequest.md)
 - [CreateRoleRequest](docs/CreateRoleRequest.md)
 - [CreateRoleScopeRequest](docs/CreateRoleScopeRequest.md)
 - [CreateRoleUserRequest](docs/CreateRoleUserRequest.md)
 - [CreateSsoConnectorRequest](docs/CreateSsoConnectorRequest.md)
 - [CreateUserAsset200Response](docs/CreateUserAsset200Response.md)
 - [CreateUserIdentityRequest](docs/CreateUserIdentityRequest.md)
 - [CreateUserMfaVerification200Response](docs/CreateUserMfaVerification200Response.md)
 - [CreateUserMfaVerification200ResponseOneOf](docs/CreateUserMfaVerification200ResponseOneOf.md)
 - [CreateUserMfaVerification200ResponseOneOf1](docs/CreateUserMfaVerification200ResponseOneOf1.md)
 - [CreateUserMfaVerificationRequest](docs/CreateUserMfaVerificationRequest.md)
 - [CreateUserMfaVerificationRequestType](docs/CreateUserMfaVerificationRequestType.md)
 - [CreateUserRequest](docs/CreateUserRequest.md)
 - [GetActiveUserCounts200Response](docs/GetActiveUserCounts200Response.md)
 - [GetActiveUserCounts200ResponseDauCurveInner](docs/GetActiveUserCounts200ResponseDauCurveInner.md)
 - [GetAdminConsoleConfig200Response](docs/GetAdminConsoleConfig200Response.md)
 - [GetAdminConsoleConfig200ResponseCheckedChargeNotification](docs/GetAdminConsoleConfig200ResponseCheckedChargeNotification.md)
 - [GetAdminConsoleConfig200ResponseDevelopmentTenantMigrationNotification](docs/GetAdminConsoleConfig200ResponseDevelopmentTenantMigrationNotification.md)
 - [GetApplication200Response](docs/GetApplication200Response.md)
 - [GetApplicationSignInExperience200Response](docs/GetApplicationSignInExperience200Response.md)
 - [GetHasuraAuth200Response](docs/GetHasuraAuth200Response.md)
 - [GetJwtCustomizer200Response](docs/GetJwtCustomizer200Response.md)
 - [GetJwtCustomizer200ResponseOneOf](docs/GetJwtCustomizer200ResponseOneOf.md)
 - [GetJwtCustomizer200ResponseOneOf1](docs/GetJwtCustomizer200ResponseOneOf1.md)
 - [GetJwtCustomizer200ResponseOneOf1TokenSample](docs/GetJwtCustomizer200ResponseOneOf1TokenSample.md)
 - [GetJwtCustomizer200ResponseOneOfContextSample](docs/GetJwtCustomizer200ResponseOneOfContextSample.md)
 - [GetJwtCustomizer200ResponseOneOfContextSampleUser](docs/GetJwtCustomizer200ResponseOneOfContextSampleUser.md)
 - [GetJwtCustomizer200ResponseOneOfContextSampleUserIdentitiesValue](docs/GetJwtCustomizer200ResponseOneOfContextSampleUserIdentitiesValue.md)
 - [GetJwtCustomizer200ResponseOneOfContextSampleUserOrganizationRolesInner](docs/GetJwtCustomizer200ResponseOneOfContextSampleUserOrganizationRolesInner.md)
 - [GetJwtCustomizer200ResponseOneOfContextSampleUserProfile](docs/GetJwtCustomizer200ResponseOneOfContextSampleUserProfile.md)
 - [GetJwtCustomizer200ResponseOneOfContextSampleUserProfileAddress](docs/GetJwtCustomizer200ResponseOneOfContextSampleUserProfileAddress.md)
 - [GetJwtCustomizer200ResponseOneOfContextSampleUserRolesInner](docs/GetJwtCustomizer200ResponseOneOfContextSampleUserRolesInner.md)
 - [GetJwtCustomizer200ResponseOneOfContextSampleUserRolesInnerScopesInner](docs/GetJwtCustomizer200ResponseOneOfContextSampleUserRolesInnerScopesInner.md)
 - [GetJwtCustomizer200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource](docs/GetJwtCustomizer200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource.md)
 - [GetJwtCustomizer200ResponseOneOfContextSampleUserSsoIdentitiesInner](docs/GetJwtCustomizer200ResponseOneOfContextSampleUserSsoIdentitiesInner.md)
 - [GetJwtCustomizer200ResponseOneOfTokenSample](docs/GetJwtCustomizer200ResponseOneOfTokenSample.md)
 - [GetJwtCustomizer200ResponseOneOfTokenSampleAud](docs/GetJwtCustomizer200ResponseOneOfTokenSampleAud.md)
 - [GetNewUserCounts200Response](docs/GetNewUserCounts200Response.md)
 - [GetNewUserCounts200ResponseToday](docs/GetNewUserCounts200ResponseToday.md)
 - [GetOidcKeys200ResponseInner](docs/GetOidcKeys200ResponseInner.md)
 - [GetOrganizationInvitation200Response](docs/GetOrganizationInvitation200Response.md)
 - [GetOrganizationRole200Response](docs/GetOrganizationRole200Response.md)
 - [GetSignInExp200Response](docs/GetSignInExp200Response.md)
 - [GetSignInExp200ResponseColor](docs/GetSignInExp200ResponseColor.md)
 - [GetSignInExp200ResponseLanguageInfo](docs/GetSignInExp200ResponseLanguageInfo.md)
 - [GetSignInExp200ResponseMfa](docs/GetSignInExp200ResponseMfa.md)
 - [GetSignInExp200ResponsePasswordPolicy](docs/GetSignInExp200ResponsePasswordPolicy.md)
 - [GetSignInExp200ResponsePasswordPolicyCharacterTypes](docs/GetSignInExp200ResponsePasswordPolicyCharacterTypes.md)
 - [GetSignInExp200ResponsePasswordPolicyLength](docs/GetSignInExp200ResponsePasswordPolicyLength.md)
 - [GetSignInExp200ResponsePasswordPolicyRejects](docs/GetSignInExp200ResponsePasswordPolicyRejects.md)
 - [GetSignInExp200ResponseSignIn](docs/GetSignInExp200ResponseSignIn.md)
 - [GetSignInExp200ResponseSignInMethodsInner](docs/GetSignInExp200ResponseSignInMethodsInner.md)
 - [GetSignInExp200ResponseSignUp](docs/GetSignInExp200ResponseSignUp.md)
 - [GetSignInExp200ResponseSocialSignIn](docs/GetSignInExp200ResponseSocialSignIn.md)
 - [GetSignInExperienceConfig200Response](docs/GetSignInExperienceConfig200Response.md)
 - [GetSignInExperienceConfig200ResponseForgotPassword](docs/GetSignInExperienceConfig200ResponseForgotPassword.md)
 - [GetSignInExperienceConfig200ResponseGoogleOneTap](docs/GetSignInExperienceConfig200ResponseGoogleOneTap.md)
 - [GetSignInExperienceConfig200ResponseSocialConnectorsInner](docs/GetSignInExperienceConfig200ResponseSocialConnectorsInner.md)
 - [GetSignInExperienceConfig200ResponseSsoConnectorsInner](docs/GetSignInExperienceConfig200ResponseSsoConnectorsInner.md)
 - [GetSignInExperiencePhrases200ResponseValue](docs/GetSignInExperiencePhrases200ResponseValue.md)
 - [GetSystemApplicationConfig200Response](docs/GetSystemApplicationConfig200Response.md)
 - [GetSystemApplicationConfig200ResponseProtectedApps](docs/GetSystemApplicationConfig200ResponseProtectedApps.md)
 - [GetTotalUserCount200Response](docs/GetTotalUserCount200Response.md)
 - [GetUser200Response](docs/GetUser200Response.md)
 - [GetUser200ResponseSsoIdentitiesInner](docs/GetUser200ResponseSsoIdentitiesInner.md)
 - [GetUserAssetServiceStatus200Response](docs/GetUserAssetServiceStatus200Response.md)
 - [GetUserAssetServiceStatus200ResponseStatus](docs/GetUserAssetServiceStatus200ResponseStatus.md)
 - [GetUserHasPassword200Response](docs/GetUserHasPassword200Response.md)
 - [ListApplicationOrganizations200ResponseInner](docs/ListApplicationOrganizations200ResponseInner.md)
 - [ListApplicationOrganizations200ResponseInnerOrganizationRolesInner](docs/ListApplicationOrganizations200ResponseInnerOrganizationRolesInner.md)
 - [ListApplicationRoles200ResponseInner](docs/ListApplicationRoles200ResponseInner.md)
 - [ListApplicationUserConsentOrganizations200Response](docs/ListApplicationUserConsentOrganizations200Response.md)
 - [ListApplicationUserConsentOrganizations200ResponseOrganizationsInner](docs/ListApplicationUserConsentOrganizations200ResponseOrganizationsInner.md)
 - [ListApplicationUserConsentScopes200Response](docs/ListApplicationUserConsentScopes200Response.md)
 - [ListApplicationUserConsentScopes200ResponseOrganizationScopesInner](docs/ListApplicationUserConsentScopes200ResponseOrganizationScopesInner.md)
 - [ListApplicationUserConsentScopes200ResponseResourceScopesInner](docs/ListApplicationUserConsentScopes200ResponseResourceScopesInner.md)
 - [ListApplicationUserConsentScopes200ResponseResourceScopesInnerResource](docs/ListApplicationUserConsentScopes200ResponseResourceScopesInnerResource.md)
 - [ListApplications200ResponseInner](docs/ListApplications200ResponseInner.md)
 - [ListApplications200ResponseInnerCustomClientMetadata](docs/ListApplications200ResponseInnerCustomClientMetadata.md)
 - [ListApplications200ResponseInnerOidcClientMetadata](docs/ListApplications200ResponseInnerOidcClientMetadata.md)
 - [ListApplications200ResponseInnerOidcClientMetadataRedirectUrisInner](docs/ListApplications200ResponseInnerOidcClientMetadataRedirectUrisInner.md)
 - [ListApplications200ResponseInnerProtectedAppMetadata](docs/ListApplications200ResponseInnerProtectedAppMetadata.md)
 - [ListApplications200ResponseInnerProtectedAppMetadataCustomDomainsInner](docs/ListApplications200ResponseInnerProtectedAppMetadataCustomDomainsInner.md)
 - [ListApplications200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareData](docs/ListApplications200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareData.md)
 - [ListApplications200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareDataSsl](docs/ListApplications200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareDataSsl.md)
 - [ListApplications200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareDataSslValidationErrorsInner](docs/ListApplications200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareDataSslValidationErrorsInner.md)
 - [ListApplications200ResponseInnerProtectedAppMetadataCustomDomainsInnerDnsRecordsInner](docs/ListApplications200ResponseInnerProtectedAppMetadataCustomDomainsInnerDnsRecordsInner.md)
 - [ListApplications200ResponseInnerProtectedAppMetadataPageRulesInner](docs/ListApplications200ResponseInnerProtectedAppMetadataPageRulesInner.md)
 - [ListApplicationsIsThirdPartyParameter](docs/ListApplicationsIsThirdPartyParameter.md)
 - [ListApplicationsTypesParameter](docs/ListApplicationsTypesParameter.md)
 - [ListConnectorFactories200ResponseInner](docs/ListConnectorFactories200ResponseInner.md)
 - [ListConnectors200ResponseInner](docs/ListConnectors200ResponseInner.md)
 - [ListConnectors200ResponseInnerFormItemsInner](docs/ListConnectors200ResponseInnerFormItemsInner.md)
 - [ListConnectors200ResponseInnerFormItemsInnerOneOf](docs/ListConnectors200ResponseInnerFormItemsInnerOneOf.md)
 - [ListConnectors200ResponseInnerFormItemsInnerOneOf1](docs/ListConnectors200ResponseInnerFormItemsInnerOneOf1.md)
 - [ListConnectors200ResponseInnerFormItemsInnerOneOf1SelectItemsInner](docs/ListConnectors200ResponseInnerFormItemsInnerOneOf1SelectItemsInner.md)
 - [ListConnectors200ResponseInnerFormItemsInnerOneOf2](docs/ListConnectors200ResponseInnerFormItemsInnerOneOf2.md)
 - [ListConnectors200ResponseInnerFormItemsInnerOneOfSelectItemsInner](docs/ListConnectors200ResponseInnerFormItemsInnerOneOfSelectItemsInner.md)
 - [ListConnectors200ResponseInnerFormItemsInnerOneOfShowConditionsInner](docs/ListConnectors200ResponseInnerFormItemsInnerOneOfShowConditionsInner.md)
 - [ListConnectors200ResponseInnerMetadata](docs/ListConnectors200ResponseInnerMetadata.md)
 - [ListCustomPhrases200ResponseInner](docs/ListCustomPhrases200ResponseInner.md)
 - [ListDomains200ResponseInner](docs/ListDomains200ResponseInner.md)
 - [ListHookRecentLogs200ResponseInner](docs/ListHookRecentLogs200ResponseInner.md)
 - [ListHooks200ResponseInner](docs/ListHooks200ResponseInner.md)
 - [ListHooks200ResponseInnerConfig](docs/ListHooks200ResponseInnerConfig.md)
 - [ListHooks200ResponseInnerExecutionStats](docs/ListHooks200ResponseInnerExecutionStats.md)
 - [ListJwtCustomizers200ResponseInner](docs/ListJwtCustomizers200ResponseInner.md)
 - [ListJwtCustomizers200ResponseInnerOneOf](docs/ListJwtCustomizers200ResponseInnerOneOf.md)
 - [ListJwtCustomizers200ResponseInnerOneOf1](docs/ListJwtCustomizers200ResponseInnerOneOf1.md)
 - [ListLogs200ResponseInner](docs/ListLogs200ResponseInner.md)
 - [ListLogs200ResponseInnerPayload](docs/ListLogs200ResponseInnerPayload.md)
 - [ListLogs200ResponseInnerPayloadError](docs/ListLogs200ResponseInnerPayloadError.md)
 - [ListOrganizationApplications200ResponseInner](docs/ListOrganizationApplications200ResponseInner.md)
 - [ListOrganizationJitEmailDomains200ResponseInner](docs/ListOrganizationJitEmailDomains200ResponseInner.md)
 - [ListOrganizationJitSsoConnectors200ResponseInner](docs/ListOrganizationJitSsoConnectors200ResponseInner.md)
 - [ListOrganizationJitSsoConnectors200ResponseInnerBranding](docs/ListOrganizationJitSsoConnectors200ResponseInnerBranding.md)
 - [ListOrganizationRoleScopes200ResponseInner](docs/ListOrganizationRoleScopes200ResponseInner.md)
 - [ListOrganizationRoles200ResponseInner](docs/ListOrganizationRoles200ResponseInner.md)
 - [ListOrganizationRoles200ResponseInnerResourceScopesInner](docs/ListOrganizationRoles200ResponseInnerResourceScopesInner.md)
 - [ListOrganizationUsers200ResponseInner](docs/ListOrganizationUsers200ResponseInner.md)
 - [ListOrganizations200ResponseInner](docs/ListOrganizations200ResponseInner.md)
 - [ListResources200ResponseInner](docs/ListResources200ResponseInner.md)
 - [ListResources200ResponseInnerScopesInner](docs/ListResources200ResponseInnerScopesInner.md)
 - [ListRoleScopes200ResponseInner](docs/ListRoleScopes200ResponseInner.md)
 - [ListRoles200ResponseInner](docs/ListRoles200ResponseInner.md)
 - [ListRoles200ResponseInnerFeaturedApplicationsInner](docs/ListRoles200ResponseInnerFeaturedApplicationsInner.md)
 - [ListRoles200ResponseInnerFeaturedUsersInner](docs/ListRoles200ResponseInnerFeaturedUsersInner.md)
 - [ListSsoConnectorProviders200ResponseInner](docs/ListSsoConnectorProviders200ResponseInner.md)
 - [ListSsoConnectors200ResponseInner](docs/ListSsoConnectors200ResponseInner.md)
 - [ListUserMfaVerifications200ResponseInner](docs/ListUserMfaVerifications200ResponseInner.md)
 - [ReplaceApplicationRolesRequest](docs/ReplaceApplicationRolesRequest.md)
 - [ReplaceApplicationSignInExperienceRequest](docs/ReplaceApplicationSignInExperienceRequest.md)
 - [ReplaceApplicationSignInExperienceRequestTermsOfUseUrl](docs/ReplaceApplicationSignInExperienceRequestTermsOfUseUrl.md)
 - [ReplaceApplicationUserConsentOrganizationsRequest](docs/ReplaceApplicationUserConsentOrganizationsRequest.md)
 - [ReplaceOrganizationApplicationRolesRequest](docs/ReplaceOrganizationApplicationRolesRequest.md)
 - [ReplaceOrganizationApplicationsRequest](docs/ReplaceOrganizationApplicationsRequest.md)
 - [ReplaceOrganizationInvitationStatusRequest](docs/ReplaceOrganizationInvitationStatusRequest.md)
 - [ReplaceOrganizationJitEmailDomainsRequest](docs/ReplaceOrganizationJitEmailDomainsRequest.md)
 - [ReplaceOrganizationJitRolesRequest](docs/ReplaceOrganizationJitRolesRequest.md)
 - [ReplaceOrganizationJitSsoConnectorsRequest](docs/ReplaceOrganizationJitSsoConnectorsRequest.md)
 - [ReplaceOrganizationRoleResourceScopesRequest](docs/ReplaceOrganizationRoleResourceScopesRequest.md)
 - [ReplaceOrganizationRoleScopesRequest](docs/ReplaceOrganizationRoleScopesRequest.md)
 - [ReplaceOrganizationUserRolesRequest](docs/ReplaceOrganizationUserRolesRequest.md)
 - [ReplaceOrganizationUsersRequest](docs/ReplaceOrganizationUsersRequest.md)
 - [ReplaceUserIdentityRequest](docs/ReplaceUserIdentityRequest.md)
 - [RotateOidcKeysRequest](docs/RotateOidcKeysRequest.md)
 - [TestJwtCustomizerRequest](docs/TestJwtCustomizerRequest.md)
 - [TestJwtCustomizerRequestOneOf](docs/TestJwtCustomizerRequestOneOf.md)
 - [TestJwtCustomizerRequestOneOf1](docs/TestJwtCustomizerRequestOneOf1.md)
 - [TestJwtCustomizerRequestPayload](docs/TestJwtCustomizerRequestPayload.md)
 - [Translation](docs/Translation.md)
 - [TranslationObject](docs/TranslationObject.md)
 - [UpdateAdminConsoleConfigRequest](docs/UpdateAdminConsoleConfigRequest.md)
 - [UpdateApplicationRequest](docs/UpdateApplicationRequest.md)
 - [UpdateApplicationRequestOidcClientMetadata](docs/UpdateApplicationRequestOidcClientMetadata.md)
 - [UpdateApplicationRequestProtectedAppMetadata](docs/UpdateApplicationRequestProtectedAppMetadata.md)
 - [UpdateConnectorRequest](docs/UpdateConnectorRequest.md)
 - [UpdateConnectorRequestMetadata](docs/UpdateConnectorRequestMetadata.md)
 - [UpdateHook200Response](docs/UpdateHook200Response.md)
 - [UpdateHookRequest](docs/UpdateHookRequest.md)
 - [UpdateOrganizationRequest](docs/UpdateOrganizationRequest.md)
 - [UpdateOrganizationRoleRequest](docs/UpdateOrganizationRoleRequest.md)
 - [UpdateOrganizationScopeRequest](docs/UpdateOrganizationScopeRequest.md)
 - [UpdateResourceIsDefaultRequest](docs/UpdateResourceIsDefaultRequest.md)
 - [UpdateResourceRequest](docs/UpdateResourceRequest.md)
 - [UpdateResourceScopeRequest](docs/UpdateResourceScopeRequest.md)
 - [UpdateRoleRequest](docs/UpdateRoleRequest.md)
 - [UpdateSignInExp200Response](docs/UpdateSignInExp200Response.md)
 - [UpdateSignInExp200ResponseColor](docs/UpdateSignInExp200ResponseColor.md)
 - [UpdateSignInExp200ResponseLanguageInfo](docs/UpdateSignInExp200ResponseLanguageInfo.md)
 - [UpdateSignInExp200ResponseMfa](docs/UpdateSignInExp200ResponseMfa.md)
 - [UpdateSignInExp200ResponsePasswordPolicy](docs/UpdateSignInExp200ResponsePasswordPolicy.md)
 - [UpdateSignInExp200ResponseSignIn](docs/UpdateSignInExp200ResponseSignIn.md)
 - [UpdateSignInExp200ResponseSignUp](docs/UpdateSignInExp200ResponseSignUp.md)
 - [UpdateSignInExpRequest](docs/UpdateSignInExpRequest.md)
 - [UpdateSignInExpRequestColor](docs/UpdateSignInExpRequestColor.md)
 - [UpdateSignInExpRequestLanguageInfo](docs/UpdateSignInExpRequestLanguageInfo.md)
 - [UpdateSignInExpRequestSignIn](docs/UpdateSignInExpRequestSignIn.md)
 - [UpdateSignInExpRequestSignUp](docs/UpdateSignInExpRequestSignUp.md)
 - [UpdateSignInExpRequestTermsOfUseUrl](docs/UpdateSignInExpRequestTermsOfUseUrl.md)
 - [UpdateSsoConnectorRequest](docs/UpdateSsoConnectorRequest.md)
 - [UpdateUser200Response](docs/UpdateUser200Response.md)
 - [UpdateUserCustomDataRequest](docs/UpdateUserCustomDataRequest.md)
 - [UpdateUserIsSuspendedRequest](docs/UpdateUserIsSuspendedRequest.md)
 - [UpdateUserPasswordRequest](docs/UpdateUserPasswordRequest.md)
 - [UpdateUserProfileRequest](docs/UpdateUserProfileRequest.md)
 - [UpdateUserProfileRequestProfile](docs/UpdateUserProfileRequestProfile.md)
 - [UpdateUserRequest](docs/UpdateUserRequest.md)
 - [UpdateUserRequestAvatar](docs/UpdateUserRequestAvatar.md)
 - [UpdateUserRequestName](docs/UpdateUserRequestName.md)
 - [UpdateUserRequestPrimaryEmail](docs/UpdateUserRequestPrimaryEmail.md)
 - [UpdateUserRequestPrimaryPhone](docs/UpdateUserRequestPrimaryPhone.md)
 - [UpdateUserRequestUsername](docs/UpdateUserRequestUsername.md)
 - [UpsertJwtCustomizerRequest](docs/UpsertJwtCustomizerRequest.md)
 - [VerifyUserPasswordRequest](docs/VerifyUserPasswordRequest.md)
 - [VerifyVerificationCodeRequest](docs/VerifyVerificationCodeRequest.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ManagementApi"></a>
### ManagementApi

- **Type**: Bearer authentication (JWT)


## Author




